engine package - fastlob

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# engine package

## Submodules

## engine.engine module

The engine module is only responsible for executing market orders.

fastlob.engine.engine.execute(order, side)

  Execute a market order at a given side.

  Return type:

    `ResultBuilder`

fastlob.engine.engine.fill_last_order(side, order, result)

  Partially fill the last order left with what’s left of our order.

fastlob.engine.engine.fill_whole_limits(side, order, result)

  While the order to execute is larger than entire limits, fill them.

  Return type:

    `bool`

fastlob.engine.engine.fill_whole_orders(side, order, result)

  While the order to execute is larger than whole orders, fill them.

  Return type:

    `bool`

fastlob.engine.engine.mk_oop_msg(p, q)

fastlob.engine.engine.oop(order, lim_price)

  True if order is out of price.

  Return type:

    `bool`

## Module contents

The engine module is only responsible for executing market orders.